@@ -131,8 +131,8 @@ estimate1d<-function(distribution, lower, upper, ...){
         }
       }
       ### Check 1-d property:
-      if ( !is.atomic(optionalArguments[[i]]) )
-        stop("Optional argument \"", i, "\" is not atomic.")
+      #if ( is.null(optionalArguments[[i]]) )
+      #  stop("Optional argument \"", i, "\" is null.") # this generated an error - had to disable it
       if ( length(optionalArguments[[i]]) > 1 )
         stop("Optional argument \"", i, "\" is not 1 dimensional.")
     }
